@@ -49,7 +49,8 @@ def stock_price_prediction():
     return choice([-1, 1])
 
 
-def get_wf_json(url = "https://www.jma.go.jp/bosai/forecast/data/forecast/130000.json"):
+def get_wf_json(code=13):
+    url = f"https://www.jma.go.jp/bosai/forecast/data/forecast/{code}0000.json"
     resp = requests.get(url)
     d = loads(resp.text)
     return d
@@ -80,10 +81,10 @@ def f2c(f):
     return int((f-32)*(5/9))
 
 
-def ppl():
+def ppl(code=13):
     """
     東京の直近の降水確率を返す
-    6時間ごと
+    6時間ごと，7つ
     """
-    d = get_wf_json()
+    d = get_wf_json(code)
     return [int(x) for x in d[0]["timeSeries"][1]["areas"][0]["pops"]]
\ No newline at end of file
